<?php

namespace Litepie\Master\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Master\Http\Requests\DistributionareaRequest;
use Litepie\Master\Interfaces\DistributionareaRepositoryInterface;
use Litepie\Master\Models\Distributionarea;

/**
 * Resource controller class for distributionarea.
 */
class DistributionareaResourceController extends BaseController
{

    /**
     * Initialize distributionarea resource controller.
     *
     * @param type DistributionareaRepositoryInterface $distributionarea
     *
     * @return null
     */
    public function __construct(DistributionareaRepositoryInterface $distributionarea)
    {
        parent::__construct();
        $this->repository = $distributionarea;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Master\Repositories\Criteria\DistributionareaResourceCriteria::class);
    }

    /**
     * Display a list of distributionarea.
     *
     * @return Response
     */
    public function index(DistributionareaRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Master\Repositories\Presenter\DistributionareaPresenter::class)
                ->$function();
        }

        $distributionareas = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('master::distributionarea.names'))
            ->view('master::distributionarea.index', true)
            ->data(compact('distributionareas', 'view'))
            ->output();
    }

    /**
     * Display distributionarea.
     *
     * @param Request $request
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function show(DistributionareaRequest $request, Distributionarea $distributionarea)
    {

        if ($distributionarea->exists) {
            $view = 'master::distributionarea.show';
        } else {
            $view = 'master::distributionarea.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('master::distributionarea.name'))
            ->data(compact('distributionarea'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new distributionarea.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DistributionareaRequest $request)
    {

        $distributionarea = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('master::distributionarea.name')) 
            ->view('master::distributionarea.create', true) 
            ->data(compact('distributionarea'))
            ->output();
    }

    /**
     * Create new distributionarea.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DistributionareaRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $distributionarea                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('master::distributionarea.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('master/distributionarea/' . $distributionarea->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/master/distributionarea'))
                ->redirect();
        }

    }

    /**
     * Show distributionarea for editing.
     *
     * @param Request $request
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function edit(DistributionareaRequest $request, Distributionarea $distributionarea)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('master::distributionarea.name'))
            ->view('master::distributionarea.edit', true)
            ->data(compact('distributionarea'))
            ->output();
    }

    /**
     * Update the distributionarea.
     *
     * @param Request $request
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function update(DistributionareaRequest $request, Distributionarea $distributionarea)
    {
        try {
            $attributes = $request->all();

            $distributionarea->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('master::distributionarea.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('master/distributionarea/' . $distributionarea->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master/distributionarea/' . $distributionarea->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the distributionarea.
     *
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function destroy(DistributionareaRequest $request, Distributionarea $distributionarea)
    {
        try {

            $distributionarea->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('master::distributionarea.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('master/distributionarea/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master/distributionarea/' . $distributionarea->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple distributionarea.
     *
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function delete(DistributionareaRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('master::distributionarea.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('master/distributionarea'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/master/distributionarea'))
                ->redirect();
        }

    }

    /**
     * Restore deleted distributionareas.
     *
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function restore(DistributionareaRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('master::distributionarea.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/master/distributionarea'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/master/distributionarea/'))
                ->redirect();
        }

    }

}
