<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Masters\Http\Requests\LinkinfoRequest;
use Litepie\Masters\Interfaces\LinkinfoRepositoryInterface;
use Litepie\Masters\Models\Linkinfo;

/**
 * Resource controller class for linkinfo.
 */
class LinkinfoResourceController extends BaseController
{

    /**
     * Initialize linkinfo resource controller.
     *
     * @param type LinkinfoRepositoryInterface $linkinfo
     *
     * @return null
     */
    public function __construct(LinkinfoRepositoryInterface $linkinfo)
    {
        parent::__construct();
        $this->repository = $linkinfo;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Masters\Repositories\Criteria\LinkinfoResourceCriteria::class);
    }

    /**
     * Display a list of linkinfo.
     *
     * @return Response
     */
    public function index(LinkinfoRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Masters\Repositories\Presenter\LinkinfoPresenter::class)
                ->$function();
        }

        $linkinfos = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('masters::linkinfo.names'))
            ->view('masters::linkinfo.index', true)
            ->data(compact('linkinfos', 'view'))
            ->output();
    }

    /**
     * Display linkinfo.
     *
     * @param Request $request
     * @param Model   $linkinfo
     *
     * @return Response
     */
    public function show(LinkinfoRequest $request, Linkinfo $linkinfo)
    {

        if ($linkinfo->exists) {
            $view = 'masters::linkinfo.show';
        } else {
            $view = 'masters::linkinfo.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('masters::linkinfo.name'))
            ->data(compact('linkinfo'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new linkinfo.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LinkinfoRequest $request)
    {

        $linkinfo = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('masters::linkinfo.name')) 
            ->view('masters::linkinfo.create', true) 
            ->data(compact('linkinfo'))
            ->output();
    }

    /**
     * Create new linkinfo.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LinkinfoRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $linkinfo                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('masters::linkinfo.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/linkinfo/' . $linkinfo->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/masters/linkinfo'))
                ->redirect();
        }

    }

    /**
     * Show linkinfo for editing.
     *
     * @param Request $request
     * @param Model   $linkinfo
     *
     * @return Response
     */
    public function edit(LinkinfoRequest $request, Linkinfo $linkinfo)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('masters::linkinfo.name'))
            ->view('masters::linkinfo.edit', true)
            ->data(compact('linkinfo'))
            ->output();
    }

    /**
     * Update the linkinfo.
     *
     * @param Request $request
     * @param Model   $linkinfo
     *
     * @return Response
     */
    public function update(LinkinfoRequest $request, Linkinfo $linkinfo)
    {
        try {
            $attributes = $request->all();

            $linkinfo->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('masters::linkinfo.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/linkinfo/' . $linkinfo->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/linkinfo/' . $linkinfo->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the linkinfo.
     *
     * @param Model   $linkinfo
     *
     * @return Response
     */
    public function destroy(LinkinfoRequest $request, Linkinfo $linkinfo)
    {
        try {

            $linkinfo->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::linkinfo.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('masters/linkinfo/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/linkinfo/' . $linkinfo->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple linkinfo.
     *
     * @param Model   $linkinfo
     *
     * @return Response
     */
    public function delete(LinkinfoRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::linkinfo.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('masters/linkinfo'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/linkinfo'))
                ->redirect();
        }

    }

    /**
     * Restore deleted linkinfos.
     *
     * @param Model   $linkinfo
     *
     * @return Response
     */
    public function restore(LinkinfoRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('masters::linkinfo.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/masters/linkinfo'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/linkinfo/'))
                ->redirect();
        }

    }

}
