<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Masters\Http\Requests\MediatypeRequest;
use Litepie\Masters\Interfaces\MediatypeRepositoryInterface;
use Litepie\Masters\Models\Mediatype;

/**
 * Resource controller class for mediatype.
 */
class MediatypeResourceController extends BaseController
{

    /**
     * Initialize mediatype resource controller.
     *
     * @param type MediatypeRepositoryInterface $mediatype
     *
     * @return null
     */
    public function __construct(MediatypeRepositoryInterface $mediatype)
    {
        parent::__construct();
        $this->repository = $mediatype;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Masters\Repositories\Criteria\MediatypeResourceCriteria::class);
    }

    /**
     * Display a list of mediatype.
     *
     * @return Response
     */
    public function index(MediatypeRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Masters\Repositories\Presenter\MediatypePresenter::class)
                ->$function();
        }

        $mediatypes = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('masters::mediatype.names'))
            ->view('masters::mediatype.index', true)
            ->data(compact('mediatypes', 'view'))
            ->output();
    }

    /**
     * Display mediatype.
     *
     * @param Request $request
     * @param Model   $mediatype
     *
     * @return Response
     */
    public function show(MediatypeRequest $request, Mediatype $mediatype)
    {

        if ($mediatype->exists) {
            $view = 'masters::mediatype.show';
        } else {
            $view = 'masters::mediatype.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('masters::mediatype.name'))
            ->data(compact('mediatype'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new mediatype.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MediatypeRequest $request)
    {

        $mediatype = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('masters::mediatype.name')) 
            ->view('masters::mediatype.create', true) 
            ->data(compact('mediatype'))
            ->output();
    }

    /**
     * Create new mediatype.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MediatypeRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $mediatype                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('masters::mediatype.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/mediatype/' . $mediatype->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/masters/mediatype'))
                ->redirect();
        }

    }

    /**
     * Show mediatype for editing.
     *
     * @param Request $request
     * @param Model   $mediatype
     *
     * @return Response
     */
    public function edit(MediatypeRequest $request, Mediatype $mediatype)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('masters::mediatype.name'))
            ->view('masters::mediatype.edit', true)
            ->data(compact('mediatype'))
            ->output();
    }

    /**
     * Update the mediatype.
     *
     * @param Request $request
     * @param Model   $mediatype
     *
     * @return Response
     */
    public function update(MediatypeRequest $request, Mediatype $mediatype)
    {
        try {
            $attributes = $request->all();

            $mediatype->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('masters::mediatype.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/mediatype/' . $mediatype->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/mediatype/' . $mediatype->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the mediatype.
     *
     * @param Model   $mediatype
     *
     * @return Response
     */
    public function destroy(MediatypeRequest $request, Mediatype $mediatype)
    {
        try {

            $mediatype->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::mediatype.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('masters/mediatype/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/mediatype/' . $mediatype->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple mediatype.
     *
     * @param Model   $mediatype
     *
     * @return Response
     */
    public function delete(MediatypeRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::mediatype.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('masters/mediatype'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/mediatype'))
                ->redirect();
        }

    }

    /**
     * Restore deleted mediatypes.
     *
     * @param Model   $mediatype
     *
     * @return Response
     */
    public function restore(MediatypeRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('masters::mediatype.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/masters/mediatype'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/mediatype/'))
                ->redirect();
        }

    }

}
