<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Masters\Http\Requests\StatusRequest;
use Litepie\Masters\Interfaces\StatusRepositoryInterface;
use Litepie\Masters\Models\Status;

/**
 * Resource controller class for status.
 */
class StatusResourceController extends BaseController
{

    /**
     * Initialize status resource controller.
     *
     * @param type StatusRepositoryInterface $status
     *
     * @return null
     */
    public function __construct(StatusRepositoryInterface $status)
    {
        parent::__construct();
        $this->repository = $status;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Masters\Repositories\Criteria\StatusResourceCriteria::class);
    }

    /**
     * Display a list of status.
     *
     * @return Response
     */
    public function index(StatusRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Masters\Repositories\Presenter\StatusPresenter::class)
                ->$function();
        }

        $statuses = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('masters::status.names'))
            ->view('masters::status.index', true)
            ->data(compact('statuses', 'view'))
            ->output();
    }

    /**
     * Display status.
     *
     * @param Request $request
     * @param Model   $status
     *
     * @return Response
     */
    public function show(StatusRequest $request, Status $status)
    {

        if ($status->exists) {
            $view = 'masters::status.show';
        } else {
            $view = 'masters::status.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('masters::status.name'))
            ->data(compact('status'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new status.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(StatusRequest $request)
    {

        $status = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('masters::status.name')) 
            ->view('masters::status.create', true) 
            ->data(compact('status'))
            ->output();
    }

    /**
     * Create new status.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(StatusRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $status                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('masters::status.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/status/' . $status->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/masters/status'))
                ->redirect();
        }

    }

    /**
     * Show status for editing.
     *
     * @param Request $request
     * @param Model   $status
     *
     * @return Response
     */
    public function edit(StatusRequest $request, Status $status)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('masters::status.name'))
            ->view('masters::status.edit', true)
            ->data(compact('status'))
            ->output();
    }

    /**
     * Update the status.
     *
     * @param Request $request
     * @param Model   $status
     *
     * @return Response
     */
    public function update(StatusRequest $request, Status $status)
    {
        try {
            $attributes = $request->all();

            $status->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('masters::status.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/status/' . $status->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/status/' . $status->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the status.
     *
     * @param Model   $status
     *
     * @return Response
     */
    public function destroy(StatusRequest $request, Status $status)
    {
        try {

            $status->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::status.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('masters/status/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/status/' . $status->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple status.
     *
     * @param Model   $status
     *
     * @return Response
     */
    public function delete(StatusRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::status.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('masters/status'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/status'))
                ->redirect();
        }

    }

    /**
     * Restore deleted statuses.
     *
     * @param Model   $status
     *
     * @return Response
     */
    public function restore(StatusRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('masters::status.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/masters/status'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/status/'))
                ->redirect();
        }

    }

}
