<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Masters\Http\Requests\TargetgroupRequest;
use Litepie\Masters\Interfaces\TargetgroupRepositoryInterface;
use Litepie\Masters\Models\Targetgroup;

/**
 * Resource controller class for targetgroup.
 */
class TargetgroupResourceController extends BaseController
{

    /**
     * Initialize targetgroup resource controller.
     *
     * @param type TargetgroupRepositoryInterface $targetgroup
     *
     * @return null
     */
    public function __construct(TargetgroupRepositoryInterface $targetgroup)
    {
        parent::__construct();
        $this->repository = $targetgroup;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Masters\Repositories\Criteria\TargetgroupResourceCriteria::class);
    }

    /**
     * Display a list of targetgroup.
     *
     * @return Response
     */
    public function index(TargetgroupRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Masters\Repositories\Presenter\TargetgroupPresenter::class)
                ->$function();
        }

        $targetgroups = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('masters::targetgroup.names'))
            ->view('masters::targetgroup.index', true)
            ->data(compact('targetgroups', 'view'))
            ->output();
    }

    /**
     * Display targetgroup.
     *
     * @param Request $request
     * @param Model   $targetgroup
     *
     * @return Response
     */
    public function show(TargetgroupRequest $request, Targetgroup $targetgroup)
    {

        if ($targetgroup->exists) {
            $view = 'masters::targetgroup.show';
        } else {
            $view = 'masters::targetgroup.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('masters::targetgroup.name'))
            ->data(compact('targetgroup'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new targetgroup.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TargetgroupRequest $request)
    {

        $targetgroup = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('masters::targetgroup.name')) 
            ->view('masters::targetgroup.create', true) 
            ->data(compact('targetgroup'))
            ->output();
    }

    /**
     * Create new targetgroup.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TargetgroupRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $targetgroup                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('masters::targetgroup.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/targetgroup/' . $targetgroup->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/masters/targetgroup'))
                ->redirect();
        }

    }

    /**
     * Show targetgroup for editing.
     *
     * @param Request $request
     * @param Model   $targetgroup
     *
     * @return Response
     */
    public function edit(TargetgroupRequest $request, Targetgroup $targetgroup)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('masters::targetgroup.name'))
            ->view('masters::targetgroup.edit', true)
            ->data(compact('targetgroup'))
            ->output();
    }

    /**
     * Update the targetgroup.
     *
     * @param Request $request
     * @param Model   $targetgroup
     *
     * @return Response
     */
    public function update(TargetgroupRequest $request, Targetgroup $targetgroup)
    {
        try {
            $attributes = $request->all();

            $targetgroup->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('masters::targetgroup.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('masters/targetgroup/' . $targetgroup->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/targetgroup/' . $targetgroup->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the targetgroup.
     *
     * @param Model   $targetgroup
     *
     * @return Response
     */
    public function destroy(TargetgroupRequest $request, Targetgroup $targetgroup)
    {
        try {

            $targetgroup->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::targetgroup.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('masters/targetgroup/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('masters/targetgroup/' . $targetgroup->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple targetgroup.
     *
     * @param Model   $targetgroup
     *
     * @return Response
     */
    public function delete(TargetgroupRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('masters::targetgroup.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('masters/targetgroup'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/targetgroup'))
                ->redirect();
        }

    }

    /**
     * Restore deleted targetgroups.
     *
     * @param Model   $targetgroup
     *
     * @return Response
     */
    public function restore(TargetgroupRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('masters::targetgroup.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/masters/targetgroup'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/masters/targetgroup/'))
                ->redirect();
        }

    }

}
